@@ -55,7 +55,8 @@ class Imdb:
             return False
 
         #get the full cast information
-        result["data"]["credits"] = self.get_credits(imdb_id)
+        if 'credits' in result["data"]:
+            result["data"]["credits"] = self.get_credits(imdb_id)
 
         if self.exclude_episodes is True and result["data"].get('type') == 'tv_episode':
             return False
@@ -100,7 +101,7 @@ class Imdb:
                 id_num = id_num.zfill(7)
             return 'tt' + id_num
         else:
-            return False
+            return ValueError('Could not validate ID')
 
     def find_by_title(self, title):
         default_find_by_title_params = {'json': '1',
